/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, el {1}. de {2}"

, "Recurrances"
: "Recurrències"

, "No recurring rule defined"
: "No s'ha definit cap regla de recurrència"

, "Details"
: ""

, "None"
: "Cap"

, "Daily"
: "Diàriament"

, "Weekly"
: "Setmanalment"

, "Monthly"
: "Mensualment"

, "Yearly"
: "Anualment"

, "Exceptions of reccuring events can't have recurrences themselves."
: ""

, "at"
: "a"

, "never"
: ""

, "after {0} occurrences"
: ""

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Finalització"

, "Until has to be after event start"
: "Fins ha de ser posterior a l'inici de l'esdeveniment"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "Cada dia {0}"

, "Every {0}. Week at"
: "Cada setmana {0}"

, "Every {0}. Month"
: "Cada mes {0}"

, "at the"
: "a les / als"

, "first"
: "primer"

, "second"
: "segon"

, "third"
: "tercer"

, "fourth"
: "quart"

, "last"
: "darrer"

, "Every {0}. Year"
: "Cada any {0}"

, "of"
: "de"

, "Summary"
: "Resum"

, "Organizer"
: "Organitzador"

, "Description"
: "Descripció"

, "Location"
: "Ubicació"

, "Start Time"
: "Hora d'inici"

, "End Time"
: "Hora d'acabament"

, "Attendee"
: "Assistents"

, "whole day"
: "tot el dia"

, "Week {0} :"
: ""

, "Poll, Polls"
: [
  ""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Nou esdeveniment"

, "Calendar, Calendars"
: [
  "Calendari"
 ,"Calendaris"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: ""

, "Sort Attendee"
: ""

, "Check to filter for this attendee"
: ""

, "Unavailable"
: ""

, "Loading events, please wait..."
: "S'estan carregant els esdeveniments, espereu..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: ""

, "Loose-Leaf"
: ""

, "Sheet"
: ""

, "Grid"
: ""

, "Timeline"
: ""

, "Day"
: "Dia"

, "Week"
: "Setmana"

, "Month"
: "Mes"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: ""

, "Copy {0}"
: ""

, "Set event status"
: ""

, "Updating event in the past"
: ""

, "Update this event"
: ""

, "Do not update this event"
: ""

, "Creating event in the past"
: ""

, "Create this event"
: ""

, "Do not create this event"
: ""

, "Update this event only"
: "Actualitza només aquest esdeveniment"

, "Update this and all future events"
: ""

, "Update whole series"
: "Actualitza les sèries completes"

, "Update nothing"
: "No actualitzis res"

, "Update Event"
: "Actualitza esdeveniment"

, "Please Change Selection"
: "Canvieu la selecció"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Aquesta selecció conté esdeveniments recurrents. Els esdeveniments recurrents s'han d'eliminar per separat!"

, "Delete Event"
: "Elimina esdeveniment"

, "Delete this event only"
: "Elimina només aquest esdeveniment"

, "Delete this and all future events"
: "Elimina aquest esdeveniment i tots els posteriors"

, "Delete whole series"
: "Elimina sèries completes"

, "Delete nothing"
: ""

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Esteu segur que voleu eliminar aquest esdeveniment?"
 ,"Esteu segur que voleu eliminar els {0} esdeveniments seleccionats?"

]
, "Could not Print"
: ""

, "Sorry, your current view does not support printing."
: ""

, "Scheduling Conflict"
: "Conflicte a la planificació"

, "The following attendee are busy at the requested time:"
: "L'assistent següent es troba ocupat a l'hora en qüestió:"

, "Ignore Conflict"
: "Ignora el conflicte"

, "Edit Event"
: "Edita l'esdeveniment"

, "Cancel this action"
: ""

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Gestiona els recursos"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Selecciona assistents"

, "Attachments"
: ""

, "Private"
: "Privat"

, "Tags"
: ""

, "Blocking"
: "Blocant"

, "Tentative"
: "Temptativa"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: ""

, "recurring event"
: ""

, "recurring event exception"
: ""

, "has alarm"
: ""

, "has attachments"
: ""

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Minicalendari"

, "WK"
: "set."

, "{0} more..."
: "{0} més..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: ""

, "Role"
: "Rol"

, "Select Role"
: ""

, "Status"
: "Estat"

, "Select Status"
: ""

, "Adding {0} Attendee to event"
: ""

, "no events found"
: ""

, "Searching..."
: ""

, "Search Event"
: ""

, "Event, Events"
: [
  "Esdeveniment"
 ,"Esdeveniments"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "no blocant"

, "Displayed in"
: ""

, "No Information"
: "Sense informació"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Esdeveniments"

, "Calendars"
: "Calendaris"

, "Quick Search"
: ""

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Estat de l'assistent"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: ""

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Classificació"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: ""

, "{0} {1} o'clock"
: "{0} {1} en punt"

, "Event (as attendee)"
: ""

, "Event (as organizer)"
: ""

, "Event attendee"
: ""

, "Attender, Attendee"
: [
  ""
 ,""

]
, "Resource, Resources"
: [
  "Recurs"
 ,"Recursos"

]
, "Resources"
: "Recursos"

, "Anyone"
: ""

, "Name"
: "Nom"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "Correu electrònic"

, "Maximum number of attendee"
: ""

, "Type"
: "Tipus"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Feu clic aquí per a convidar un altre organitzador"

, "User"
: "Usuari"

, "Group"
: "Grup"

, "Member of group"
: ""

, "This is the calendar where the attender has saved this event in"
: "Aquest és el calendari en què l'organitzador ha desat l'esdeveniment"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Elimina organitzador"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(com a membre de grup)"

, "External Attendee"
: ""

, "Originally"
: "Originàriament"

, "Checking Calendar Data..."
: ""

, "Reply to Recurring Event"
: ""

, "You are responding to an recurring event. What would you like to do?"
: ""

, "Respond to whole series"
: ""

, "Do not respond"
: ""

, "The event of this message does not exist"
: ""

, "The sender is not authorised to update the event"
: ""

, "This message is already processed"
: ""

, "You are not an attendee of this event"
: ""

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: ""

, "This is an event invitation for someone else."
: ""

, "You have already replied to this event invitation."
: ""

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: ""

, "An invited attendee responded to the invitation."
: ""

, "Unsupported method"
: ""

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Introduïu una descripció"

, "Grants"
: ""

, "This event is originally stored in a calendar you don't have access to."
: ""

, "This event is originally stored in {0}"
: ""

, "This event is additionally displayed in your personal calendar {0}"
: ""

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: ""

, "Saved in"
: ""

, "Enter description"
: "Introduïu una descripció"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "La data de finalització no és vàlida"

, "End date must be after start date"
: "La data de finalització ha de ser posterior a la d'inici"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "La data d'inici no és vàlida"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: ""

, "The summary must have at least 1 character."
: ""

, "Summary too Long"
: ""

, "Summary too Short"
: ""

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Tots els meus esdeveniments"

, "Position on the left time axis, day and week view should start with"
: ""

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Calendari per defecte"

, "The default calendar for invitations and new events"
: "El calendari per defecte per a invitacions i per a nous esdeveniments"

, "Default Favorite"
: "Preferit per defecte"

, "The default favorite which is loaded on calendar startup"
: "El preferit per defecte que es carrega a l'inici del calendari"

, "Get Notification Emails"
: "Rep correus electrònics de notificació"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "El nivell de les accions de les quals voleu que se us notifiqui. Observeu que els organitzadors rebran notificacions de tota actualització incloent les respostes dels assistents a menys que establiu aquesta opció a \"Mai\""

, "Send Notifications Emails of own Actions"
: "Envia correus electrònics de notificació de les pròpies accions"

, "Get notifications emails for actions you did yourself"
: "Rep correus electrònics de notificació de les accions que hagueu fet"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: ""

, "New events get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the event starts"
: ""

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: ""

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: ""

, "On invitation and cancellation only"
: ""

, "On time changes"
: ""

, "On all updates but attendee responses"
: ""

, "On attendee responses too"
: ""

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: ""

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: ""

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Sense resposta"

, "Accepted"
: "Acceptat"

, "Declined"
: "Rebutjat"

, "Attendee Roles Available"
: ""

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Obligatori"

, "Optional"
: "Opcional"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: ""

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "calendari personal de %s"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "desconegut"

, "This contact has been automatically added by the system as an event attender"
: "El sistema ha afegit automàticament aquest contacte com a organitzador de l'esdeveniment"

, "The email address has been shortened:"
: ""

, "Every %s day"
: ""

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: ""

, "Monthly every %1$s %2$s"
: ""

, "Every %1$s month on the %2$s"
: ""

, "Monthly on the %1$s"
: ""

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: ""

, "second to last"
: ""

, "fifth"
: ""

, "st"
: ""

, "nd"
: ""

, "rd"
: ""

, "th"
: ""

, "Start"
: "Inici"

, "Priority"
: "Prioritat"

, "Url"
: "Url"

, "Recurrance rule"
: "Regla de recurrència"

, "Is all day event"
: "És un esdeveniment de tot el dia"

, "Organizer timezone"
: "Zona horària de l'organitzador"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Alarma per a l'esdeveniment  \"%1$s\" a %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Invitació a esdeveniment \"%1$s\" a %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "S'ha cancel·lat l'esdeveniment \"%1$s\" a %2$s"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: ""

, "Event \"%1$s\" at %2$s has been updated"
: "S'ha actualitzat l'esdeveniment \"%1$s\" a %2$s"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s ha acceptat l'esdeveniment \"%2$s\" a %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s ha rebutjat l'esdeveniment \"%2$s\" a %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "%1$s ha respost que potser assistirà a l'esdeveniment \"%2$s\" a %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Sense resposta de %1$s per a l'esdeveniment \"%2$s\" a %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Canvis d'assistents per a l'esdeveniment \"%1$s\" a %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Actualitzacions"

, "This is an event series exception."
: ""

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s ha canviat de \"%2$s\" a \"%3$s\""

, "%1$s has been invited"
: "%1$s ha sigut convidat"

, "%1$s has been removed"
: "S'ha eliminat a %1$s"

, "%1$s accepted invitation"
: "%1$s ha acceptat la invitació"

, "%1$s declined invitation"
: "%1$s ha rebutjat la invitació"

, "Tentative response from %1$s"
: "%1$s ha respost que potser hi assistirà"

, "No response from %1$s"
: "Sense resposta de %1$s"

, "\"%2$s\" response from %1$s"
: ""

, "Link"
: ""

, "Event details"
: "Detalls de l'esdeveniment"

, "All events I attend"
: "Tots els esdeveniments als quals assisteixo"

, "Awaiting response"
: ""

, "Events I have not yet responded to"
: ""

, "Declined events"
: ""

, "Events I have declined"
: ""

, "I'm organizer"
: ""

, "Events I'm the organizer of"
: ""

, "manage shared calendars"
: "gestiona calendaris compartits"

, "Create new shared calendars"
: "Crea nous calendaris compartits"

, "manage shared calendars favorites"
: "gestiona els preferits dels calendaris compartits"

, "Create or update shared calendars favorites"
: "Crea o actualitza preferits dels calendaris compartits"

, "manage resources"
: "gestiona recursos"

, "All Rights to administrate resources"
: "Tots els permisos per a administrar recursos"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Poll"
: ""

, "Calendar"
: "Calendari"

, "Do you really want to delete this event?"
: "Esteu segur que voleu eliminar aquest esdeveniment?"

, "Resource Grant"
: ""

, "Event"
: "Esdeveniment"

, "Attender"
: ""

, "Resource"
: "Recurs"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
